codebases — Transifex v0.9.0 documentation

# Transifex v0.9.0 documentation

# `codebases`

## Models

## Library

`get_browser_class`(codebase_type)

  Return the appropriate VCS browser class.

  Keyword arguments: codebase_type – The type of the codebase, used to decide the class to be returned.

      >>> print get_browser_class('hg')
      vcs.lib.types.hg.HgBrowser

`get_browser_object`(codebase_type)

  Return the appropriate codebase browser object.

  This is a wrapper around get_browser_class which returns a browser object, ready to be initialized.

      >>> browser = get_browser_object('hg')

`need_browser`(fn)
  Decorator to initialize the unit.browser when it is needed.